@@ -1,6 +1,6 @@
 /* -*- mode: C; c-file-style: "gnu"; indent-tabs-mode: nil; -*- */
 /*
- * Copyright (C) 2012, 2013, 2014 Red Hat, Inc.
+ * Copyright (C) 2012, 2013 Red Hat, Inc.
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -80,7 +80,6 @@ typedef struct
   SoupMessage *msgs[2];
   SoupSession *session;
   gboolean accept_ssl_errors;
-  guint pending;
   gulong cancellable_id;
   xmlOutputBuffer *buf;
 } AutodiscoverData;
@@ -96,8 +95,6 @@ ews_client_autodiscover_data_free (gpointer user_data)
 {
   AutodiscoverData *data = user_data;
 
-  g_simple_async_result_complete_in_idle (data->res);
-
   if (data->cancellable_id > 0)
     {
       g_cancellable_disconnect (data->cancellable, data->cancellable_id);
@@ -206,6 +203,10 @@ ews_client_autodiscover_response_cb (SoupSession *session, SoupMessage *msg, gpo
   xmlDoc *doc;
   xmlNode *node;
 
+  status = msg->status_code;
+  if (status == SOUP_STATUS_NONE)
+    return;
+
   error = NULL;
   op_res = FALSE;
   size = sizeof (data->msgs) / sizeof (data->msgs[0]);
@@ -215,15 +216,13 @@ ews_client_autodiscover_response_cb (SoupSession *session, SoupMessage *msg, gpo
       if (data->msgs[idx] == msg)
         break;
     }
-  if (idx == size || data->pending == 0)
+  if (idx == size)
     return;
 
   data->msgs[idx] = NULL;
-  status = msg->status_code;
 
   /* status == SOUP_STATUS_CANCELLED, if we are being aborted by the
-   * GCancellable, an SSL error or another message that was
-   * successful.
+   * GCancellable or due to an SSL error.
    */
   if (status == SOUP_STATUS_CANCELLED)
     goto out;
@@ -232,7 +231,7 @@ ews_client_autodiscover_response_cb (SoupSession *session, SoupMessage *msg, gpo
       g_set_error (&error,
                    GOA_ERROR,
                    GOA_ERROR_FAILED, /* TODO: more specific */
-                   _("Code: %u - Unexpected response from server"),
+                   _("Code: %u — Unexpected response from server"),
                    status);
       goto out;
     }
@@ -258,7 +257,8 @@ ews_client_autodiscover_response_cb (SoupSession *session, SoupMessage *msg, gpo
       g_set_error (&error,
                    GOA_ERROR,
                    GOA_ERROR_FAILED, /* TODO: more specific */
-                   _("Failed to find Autodiscover element"));
+                   /* Translators: the parameter is an XML element name. */
+                   _("Failed to find ‘%s’ element"), "Autodiscover");
       goto out;
     }
 
@@ -272,7 +272,8 @@ ews_client_autodiscover_response_cb (SoupSession *session, SoupMessage *msg, gpo
       g_set_error (&error,
                    GOA_ERROR,
                    GOA_ERROR_FAILED, /* TODO: more specific */
-                   _("Failed to find Response element"));
+                   /* Translators: the parameter is an XML element name. */
+                   _("Failed to find ‘%s’ element"), "Response");
       goto out;
     }
 
@@ -286,7 +287,8 @@ ews_client_autodiscover_response_cb (SoupSession *session, SoupMessage *msg, gpo
       g_set_error (&error,
                    GOA_ERROR,
                    GOA_ERROR_FAILED, /* TODO: more specific */
-                   _("Failed to find Account element"));
+                   /* Translators: the parameter is an XML element name. */
+                   _("Failed to find ‘%s’ element"), "Account");
       goto out;
     }
 
@@ -295,11 +297,7 @@ ews_client_autodiscover_response_cb (SoupSession *session, SoupMessage *msg, gpo
       if (ews_client_check_node (node, "Protocol"))
         {
           op_res = ews_client_autodiscover_parse_protocol (node);
-          /* Since the server may send back multiple <Protocol> nodes
-           * don't break unless we found the one we want.
-           */
-          if (op_res)
-            break;
+          break;
         }
     }
   if (!op_res)
@@ -319,43 +317,35 @@ ews_client_autodiscover_response_cb (SoupSession *session, SoupMessage *msg, gpo
            * message, the callback (ie. this function) will be invoked before
            * soup_session_cancel_message returns.
            */
-          soup_session_cancel_message (data->session, data->msgs[idx], SOUP_STATUS_CANCELLED);
+          soup_session_cancel_message (data->session, data->msgs[idx], SOUP_STATUS_NONE);
+          data->msgs[idx] = NULL;
         }
     }
 
  out:
-  /* error == NULL, if we are being aborted by the GCancellable, an
-   * SSL error or another message that was successful.
+  /* error == NULL, if we are being aborted by the GCancellable or
+   * due to an SSL error.
    */
   if (!op_res)
     {
-      /* There's another request outstanding.
-       * Hope that it has better luck.
-       */
-      if (data->pending > 1)
-        g_clear_error (&error);
-
+      for (idx = 0; idx < size; idx++)
+        {
+          if (data->msgs[idx] != NULL)
+            {
+              /* There's another request outstanding.
+               * Hope that it has better luck.
+               */
+              g_clear_error (&error);
+              return;
+            }
+        }
       if (error != NULL)
         g_simple_async_result_take_error (data->res, error);
     }
 
-  data->pending--;
-  if (data->pending == 0)
-    {
-      GMainContext *context;
-      GSource *source;
-
-      g_simple_async_result_set_op_res_gboolean (data->res, op_res);
-
-      source = g_idle_source_new ();
-      g_source_set_priority (source, G_PRIORITY_DEFAULT_IDLE);
-      g_source_set_callback (source, ews_client_autodiscover_data_free, data, NULL);
-      g_source_set_name (source, "[goa] ews_client_autodiscover_data_free");
-
-      context = g_main_context_get_thread_default ();
-      g_source_attach (source, context);
-      g_source_unref (source);
-    }
+  g_simple_async_result_set_op_res_gboolean (data->res, op_res);
+  g_simple_async_result_complete_in_idle (data->res);
+  g_idle_add (ews_client_autodiscover_data_free, data);
 }
 
 static xmlDoc *
@@ -456,10 +446,10 @@ goa_ews_client_autodiscover (GoaEwsClient        *client,
   xmlOutputBuffer *buf;
 
   g_return_if_fail (GOA_IS_EWS_CLIENT (client));
-  g_return_if_fail (email != NULL && email[0] != '\0');
-  g_return_if_fail (password != NULL && password[0] != '\0');
-  g_return_if_fail (username != NULL && username[0] != '\0');
-  g_return_if_fail (server != NULL && server[0] != '\0');
+  g_return_if_fail (email != NULL || email[0] != '\0');
+  g_return_if_fail (password != NULL || password[0] != '\0');
+  g_return_if_fail (username != NULL || username[0] != '\0');
+  g_return_if_fail (server != NULL || server[0] != '\0');
   g_return_if_fail (cancellable == NULL || G_IS_CANCELLABLE (cancellable));
 
   doc = ews_client_create_autodiscover_xml (email);
@@ -482,7 +472,6 @@ goa_ews_client_autodiscover (GoaEwsClient        *client,
   data->res = g_simple_async_result_new (G_OBJECT (client), callback, user_data, goa_ews_client_autodiscover);
   data->msgs[0] = ews_client_create_msg_for_url (url1, buf);
   data->msgs[1] = ews_client_create_msg_for_url (url2, buf);
-  data->pending = sizeof (data->msgs) / sizeof (data->msgs[0]);
   data->session = soup_session_async_new_with_options (SOUP_SESSION_SSL_USE_SYSTEM_CA_FILE, TRUE,
                                                        SOUP_SESSION_SSL_STRICT, FALSE,
                                                        SOUP_SESSION_USE_NTLM, TRUE,
