@@ -110,19 +110,19 @@ get_consumer_secret (GoaOAuthProvider *provider)
 static const gchar *
 get_request_uri (GoaOAuthProvider *provider)
 {
-  return "https://m.flickr.com/services/oauth/request_token";
+  return "http://m.flickr.com/services/oauth/request_token";
 }
 
 static const gchar *
 get_authorization_uri (GoaOAuthProvider *provider)
 {
-  return "https://m.flickr.com/services/oauth/authorize";
+  return "http://m.flickr.com/services/oauth/authorize";
 }
 
 static const gchar *
 get_token_uri (GoaOAuthProvider *provider)
 {
-  return "https://m.flickr.com/services/oauth/access_token";
+  return "http://m.flickr.com/services/oauth/access_token";
 }
 
 static const gchar *
@@ -171,7 +171,7 @@ get_identity_sync (GoaOAuthProvider  *provider,
                                       goa_oauth_provider_get_consumer_secret (provider),
                                       access_token,
                                       access_token_secret,
-                                      "https://api.flickr.com/services/rest",
+                                      "http://api.flickr.com/services/rest",
                                       FALSE);
   call = rest_proxy_new_call (proxy);
   rest_proxy_call_add_param (call, "method", "flickr.test.login");
@@ -186,7 +186,7 @@ get_identity_sync (GoaOAuthProvider  *provider,
       g_set_error (error,
                    GOA_ERROR,
                    GOA_ERROR_FAILED,
-                   _("Expected status 200 when requesting user id, instead got status %d (%s)"),
+                   _("Expected status 200 when requesting your identity, instead got status %d (%s)"),
                    rest_proxy_call_get_status_code (call),
                    rest_proxy_call_get_status_message (call));
       goto out;
@@ -346,7 +346,6 @@ build_object (GoaProvider         *provider,
   gboolean photos_enabled;
   gboolean ret;
 
-  account = NULL;
   photos = NULL;
   ret = FALSE;
 
@@ -423,6 +422,8 @@ show_account (GoaProvider         *provider,
   goa_util_add_account_info (grid, row++, object);
 
   goa_util_add_row_switch_from_keyfile_with_blurb (grid, row++, object,
+                                                   /* Translators: This is a label for a series of
+                                                    * options switches. For example: “Use for Mail”. */
                                                    _("Use for"),
                                                    "photos-disabled",
                                                    _("_Photos"));
