@@ -1,6 +1,6 @@
 /* -*- mode: C; c-file-style: "gnu"; indent-tabs-mode: nil; -*- */
 /*
- * Copyright (C) 2012, 2013, 2014 Red Hat, Inc.
+ * Copyright (C) 2012, 2013 Red Hat, Inc.
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -87,8 +87,6 @@ http_client_check_data_free (gpointer user_data)
 {
   CheckData *data = user_data;
 
-  g_simple_async_result_complete_in_idle (data->res);
-
   if (data->cancellable_id > 0)
     {
       g_cancellable_disconnect (data->cancellable, data->cancellable_id);
@@ -159,8 +157,6 @@ http_client_check_response_cb (SoupSession *session, SoupMessage *msg, gpointer
 {
   GError *error;
   CheckData *data = user_data;
-  GMainContext *context;
-  GSource *source;
   gboolean op_res;
 
   error = NULL;
@@ -176,7 +172,7 @@ http_client_check_response_cb (SoupSession *session, SoupMessage *msg, gpointer
       g_set_error (&error,
                    GOA_ERROR,
                    GOA_ERROR_FAILED, /* TODO: more specific */
-                   _("Code: %u - Unexpected response from server"),
+                   _("Code: %u — Unexpected response from server"),
                    msg->status_code);
       goto out;
     }
@@ -191,14 +187,8 @@ http_client_check_response_cb (SoupSession *session, SoupMessage *msg, gpointer
   if (error != NULL)
     g_simple_async_result_take_error (data->res, error);
 
-  source = g_idle_source_new ();
-  g_source_set_priority (source, G_PRIORITY_DEFAULT_IDLE);
-  g_source_set_callback (source, http_client_check_data_free, data, NULL);
-  g_source_set_name (source, "[goa] http_client_check_data_free");
-
-  context = g_main_context_get_thread_default ();
-  g_source_attach (source, context);
-  g_source_unref (source);
+  g_simple_async_result_complete_in_idle (data->res);
+  g_idle_add (http_client_check_data_free, data);
 }
 
 static void
@@ -230,9 +220,9 @@ goa_http_client_check (GoaHttpClient       *client,
   SoupLogger *logger;
 
   g_return_if_fail (GOA_IS_HTTP_CLIENT (client));
-  g_return_if_fail (uri != NULL && uri[0] != '\0');
-  g_return_if_fail (username != NULL && username[0] != '\0');
-  g_return_if_fail (password != NULL && password[0] != '\0');
+  g_return_if_fail (uri != NULL || uri[0] != '\0');
+  g_return_if_fail (username != NULL || username[0] != '\0');
+  g_return_if_fail (password != NULL || password[0] != '\0');
   g_return_if_fail (cancellable == NULL || G_IS_CANCELLABLE (cancellable));
 
   data = g_slice_new0 (CheckData);
