@@ -1,6 +1,6 @@
 /* -*- mode: C; c-file-style: "gnu"; indent-tabs-mode: nil; -*- */
 /*
- * Copyright (C) 2011, 2012 Red Hat, Inc.
+ * Copyright (C) 2011, 2012, 2013, 2014 Red Hat, Inc.
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -184,7 +184,10 @@ goa_oauth2_provider_is_password_node_default (GoaOAuth2Provider *provider, WebKi
  * @element: A WebKitDOMHTMLInputElement
  *
  * Checks whether @element is the HTML UI element that the user can
- * use to enter her password.
+ * use to enter her password. This can be used to offer a
+ * #GoaPasswordBased interface by saving the user's
+ * password. Providers usually frown upon doing this, so this is not
+ * recommended.
  *
  * This is a virtual method where the default implementation returns
  * %FALSE.
@@ -252,7 +255,7 @@ goa_oauth2_provider_build_authorization_uri_default (GoaOAuth2Provider  *provide
  * @authorization_uri: An authorization URI.
  * @escaped_redirect_uri: An escaped redirect URI
  * @escaped_client_id: An escaped client id
- * @escaped_scope: The escaped scope.
+ * @escaped_scope: (allow-none): The escaped scope or %NULL
  *
  * Builds the URI that can be opened in a web browser (or embedded web
  * browser widget) to start authenticating an user.
@@ -281,7 +284,6 @@ goa_oauth2_provider_build_authorization_uri (GoaOAuth2Provider  *provider,
   g_return_val_if_fail (authorization_uri != NULL, NULL);
   g_return_val_if_fail (escaped_redirect_uri != NULL, NULL);
   g_return_val_if_fail (escaped_client_id != NULL, NULL);
-  g_return_val_if_fail (escaped_scope != NULL, NULL);
   return GOA_OAUTH2_PROVIDER_GET_CLASS (provider)->build_authorization_uri (provider,
                                                                                     authorization_uri,
                                                                                     escaped_redirect_uri,
@@ -289,6 +291,43 @@ goa_oauth2_provider_build_authorization_uri (GoaOAuth2Provider  *provider,
                                                                                     escaped_scope);
 }
 
+/**
+ * goa_oauth2_provider_process_redirect_url:
+ * @provider: A #GoaOAuth2Provider.
+ * @redirect_url: A redirect URI from the web browser
+ * @authorization_code: (out): Return location for access token
+ * @error: Return location for error or %NULL
+ *
+ * Certain OAuth2-like, but not exactly <ulink
+ * url="http://tools.ietf.org/html/draft-ietf-oauth-v2-15">OAuth2</ulink>,
+ * providers do not follow the standard mechanisms for extracting the
+ * access token or auth code from the redirect URI. They use some
+ * non-standard technique to do so. This is a provider specific hook
+ * to accommodate them and will only be used if implemented.
+ *
+ * This is a pure virtual method - a subclass must provide an
+ * implementation if needed.
+ *
+ * Returns: %TRUE if @provider could process @redirect_url, %FALSE
+ * otherwise.
+ */
+gboolean
+goa_oauth2_provider_process_redirect_url (GoaOAuth2Provider  *provider,
+                                          const gchar        *redirect_url,
+                                          gchar             **authorization_code,
+                                          GError            **error)
+{
+  g_return_val_if_fail (GOA_IS_OAUTH2_PROVIDER (provider), NULL);
+  g_return_val_if_fail (redirect_url != NULL, NULL);
+  g_return_val_if_fail (authorization_code != NULL, NULL);
+  g_return_val_if_fail (error == NULL || *error == NULL, FALSE);
+
+  return GOA_OAUTH2_PROVIDER_GET_CLASS (provider)->process_redirect_url (provider,
+                                                                         redirect_url,
+                                                                         authorization_code,
+                                                                         error);
+}
+
 /**
  * goa_oauth2_provider_get_authorization_uri:
  * @provider: A #GoaOAuth2Provider.
@@ -371,6 +410,14 @@ goa_oauth2_provider_get_redirect_uri (GoaOAuth2Provider *provider)
   return GOA_OAUTH2_PROVIDER_GET_CLASS (provider)->get_redirect_uri (provider);
 }
 
+/* ---------------------------------------------------------------------------------------------------- */
+
+static const gchar *
+goa_oauth2_provider_get_scope_default (GoaOAuth2Provider *provider)
+{
+  return NULL;
+}
+
 /**
  * goa_oauth2_provider_get_scope:
  * @provider: A #GoaOAuth2Provider.
@@ -379,8 +426,8 @@ goa_oauth2_provider_get_redirect_uri (GoaOAuth2Provider *provider)
  * url="http://tools.ietf.org/html/draft-ietf-oauth-v2-15#section-2.1.1">scope</ulink>
  * used when requesting authorization.
  *
- * This is a pure virtual method - a subclass must provide an
- * implementation.
+ * This is a virtual method where the default implementation returns
+ * %NULL.
  *
  * Returns: (transfer none): A string owned by @provider - do not free.
  */
@@ -391,6 +438,8 @@ goa_oauth2_provider_get_scope (GoaOAuth2Provider *provider)
   return GOA_OAUTH2_PROVIDER_GET_CLASS (provider)->get_scope (provider);
 }
 
+/* ---------------------------------------------------------------------------------------------------- */
+
 /**
  * goa_oauth2_provider_get_client_id:
  * @provider: A #GoaOAuth2Provider.
@@ -898,12 +947,32 @@ on_web_view_navigation_policy_decision_requested (WebKitWebView             *web
   fragment = soup_uri_get_fragment (uri);
   query = soup_uri_get_query (uri);
 
-  /* Two cases:
-   * 1) we can either have the access_token and other information
+  /* Three cases:
+   * 1) we can either have the backend handle the URI for us, or
+   * 2) we can either have the access_token and other information
    *    directly in the fragment part of the URI, or
-   * 2) the auth code can be in the query part of the URI, with which
+   * 3) the auth code can be in the query part of the URI, with which
    *    we'll obtain the token later.
    */
+  if (GOA_OAUTH2_PROVIDER_GET_CLASS (provider)->process_redirect_url)
+    {
+      gchar *url;
+
+      url = soup_uri_to_string (uri, FALSE);
+      if (!goa_oauth2_provider_process_redirect_url (provider, url, &priv->access_token, &priv->error))
+        {
+          g_prefix_error (&priv->error, _("Authorization response: "));
+          priv->error->domain = GOA_ERROR;
+          priv->error->code = GOA_ERROR_NOT_AUTHORIZED;
+          response_id = GTK_RESPONSE_CLOSE;
+        }
+      else
+        response_id = GTK_RESPONSE_OK;
+
+      g_free (url);
+      goto ignore_request;
+    }
+
   if (fragment != NULL)
     {
       /* fragment is encoded into a key/value pairs for the token and
@@ -962,7 +1031,7 @@ on_web_view_navigation_policy_decision_requested (WebKitWebView             *web
       g_set_error (&priv->error,
                    GOA_ERROR,
                    GOA_ERROR_NOT_AUTHORIZED,
-                   _("Authorization response was ‘%s’"),
+                   _("Authorization response: %s"),
                    oauth2_error);
       response_id = GTK_RESPONSE_CLOSE;
     }
@@ -1003,6 +1072,7 @@ get_tokens_and_identity (GoaOAuth2Provider  *provider,
   gboolean ret;
   gchar *url;
   GtkWidget *grid;
+  const gchar *scope;
   gchar *escaped_redirect_uri;
   gchar *escaped_client_id;
   gchar *escaped_scope;
@@ -1034,7 +1104,11 @@ get_tokens_and_identity (GoaOAuth2Provider  *provider,
   /* TODO: use oauth2_proxy_build_login_url_full() */
   escaped_redirect_uri = g_uri_escape_string (goa_oauth2_provider_get_redirect_uri (provider), NULL, TRUE);
   escaped_client_id = g_uri_escape_string (goa_oauth2_provider_get_client_id (provider), NULL, TRUE);
-  escaped_scope = g_uri_escape_string (goa_oauth2_provider_get_scope (provider), NULL, TRUE);
+  scope = goa_oauth2_provider_get_scope (provider);
+  if (scope != NULL)
+    escaped_scope = g_uri_escape_string (goa_oauth2_provider_get_scope (provider), NULL, TRUE);
+  else
+    escaped_scope = NULL;
   url = goa_oauth2_provider_build_authorization_uri (provider,
                                                      goa_oauth2_provider_get_authorization_uri (provider),
                                                      escaped_redirect_uri,
@@ -1073,7 +1147,7 @@ get_tokens_and_identity (GoaOAuth2Provider  *provider,
       gtk_widget_grab_focus (entry);
       gtk_widget_show_all (GTK_WIDGET (vbox));
 
-      gtk_dialog_add_button (dialog, GTK_STOCK_OK, GTK_RESPONSE_OK);
+      gtk_dialog_add_button (dialog, _("_OK"), GTK_RESPONSE_OK);
       gtk_dialog_set_default_response (dialog, GTK_RESPONSE_OK);
       gtk_dialog_set_response_sensitive (dialog, GTK_RESPONSE_OK, FALSE);
       g_signal_connect (entry, "changed", G_CALLBACK (on_entry_changed), provider);
@@ -1356,7 +1430,7 @@ goa_oauth2_provider_refresh_account (GoaProvider  *_provider,
   dialog = gtk_dialog_new_with_buttons (NULL,
                                         parent,
                                         GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
-                                        GTK_STOCK_CANCEL, GTK_RESPONSE_REJECT,
+                                        _("_Cancel"), GTK_RESPONSE_REJECT,
                                         NULL);
   gtk_container_set_border_width (GTK_CONTAINER (dialog), 12);
   gtk_window_set_resizable (GTK_WINDOW (dialog), FALSE);
@@ -1798,6 +1872,7 @@ goa_oauth2_provider_class_init (GoaOAuth2ProviderClass *klass)
 
   klass->build_authorization_uri  = goa_oauth2_provider_build_authorization_uri_default;
   klass->get_token_uri            = goa_oauth2_provider_get_token_uri_default;
+  klass->get_scope                = goa_oauth2_provider_get_scope_default;
   klass->get_use_external_browser = goa_oauth2_provider_get_use_external_browser_default;
   klass->get_use_mobile_browser   = goa_oauth2_provider_get_use_mobile_browser_default;
   klass->is_password_node         = goa_oauth2_provider_is_password_node_default;
