@@ -1,6 +1,6 @@
 /* -*- mode: C; c-file-style: "gnu"; indent-tabs-mode: nil; -*- */
 /*
- * Copyright (C) 2011, 2012 Red Hat, Inc.
+ * Copyright (C) 2011, 2012, 2014 Red Hat, Inc.
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -28,6 +28,7 @@
 #define __GOA_OAUTH2_PROVIDER_H__
 
 #include <goabackend/goaprovider.h>
+#include <goabackend/goaprovider-priv.h>
 #include <webkit/webkit.h>
 
 G_BEGIN_DECLS
@@ -72,6 +73,7 @@ struct _GoaOAuth2Provider
  * @get_use_external_browser: Virtual function for goa_oauth2_provider_get_use_external_browser().
  * @get_use_mobile_browser: Virtual function for goa_oauth2_provider_get_use_mobile_browser().
  * @add_account_key_values: Virtual function for goa_oauth2_provider_add_account_key_values().
+ * @process_redirect_url: Virtual function for goa_oauth2_provider_process_redirect_url().
  * @is_deny_node: Virtual function for goa_oauth2_provider_is_deny_node().
  * @is_identity_node: Virtual function for goa_oauth2_provider_is_identity_node().
  * @is_password_node: Virtual function for goa_oauth2_provider_is_password_node().
@@ -85,7 +87,6 @@ struct _GoaOAuth2ProviderClass
   /* pure virtual */
   const gchar *(*get_authorization_uri)        (GoaOAuth2Provider            *provider);
   const gchar *(*get_redirect_uri)             (GoaOAuth2Provider            *provider);
-  const gchar *(*get_scope)                    (GoaOAuth2Provider            *provider);
   const gchar *(*get_client_id)                (GoaOAuth2Provider            *provider);
   const gchar *(*get_client_secret)            (GoaOAuth2Provider            *provider);
   const gchar *(*get_authentication_cookie)    (GoaOAuth2Provider            *provider);
@@ -102,6 +103,7 @@ struct _GoaOAuth2ProviderClass
                                                 const gchar                  *escaped_client_id,
                                                 const gchar                  *escaped_scope);
   const gchar *(*get_token_uri)                (GoaOAuth2Provider            *provider);
+  const gchar *(*get_scope)                    (GoaOAuth2Provider            *provider);
   gboolean     (*get_use_external_browser)     (GoaOAuth2Provider            *provider);
   gboolean     (*get_use_mobile_browser)       (GoaOAuth2Provider            *provider);
   void         (*add_account_key_values)       (GoaOAuth2Provider            *provider,
@@ -117,9 +119,15 @@ struct _GoaOAuth2ProviderClass
   gboolean     (*is_password_node)             (GoaOAuth2Provider            *provider,
                                                 WebKitDOMHTMLInputElement    *element);
 
+  gboolean     (*process_redirect_url)         (GoaOAuth2Provider            *provider,
+                                                const gchar                  *redirect_url,
+                                                gchar                       **access_token,
+                                                GError                      **error);
+
+
   /*< private >*/
   /* Padding for future expansion */
-  gpointer goa_reserved[29];
+  gpointer goa_reserved[28];
 };
 
 GType        goa_oauth2_provider_get_type                     (void) G_GNUC_CONST;
@@ -156,6 +164,10 @@ gboolean     goa_oauth2_provider_get_use_external_browser     (GoaOAuth2Provider
 gboolean     goa_oauth2_provider_get_use_mobile_browser       (GoaOAuth2Provider             *provider);
 void         goa_oauth2_provider_add_account_key_values       (GoaOAuth2Provider             *provider,
                                                                GVariantBuilder               *builder);
+gboolean     goa_oauth2_provider_process_redirect_url         (GoaOAuth2Provider             *provider,
+                                                               const gchar                   *redirect_url,
+                                                               gchar                        **authorization_code,
+                                                               GError                       **error);
 
 G_END_DECLS
 
