@@ -39,6 +39,7 @@
 #include "goaflickrprovider.h"
 #include "goawindowsliveprovider.h"
 #include "goatelepathyfactory.h"
+#include "goapocketprovider.h"
 
 #ifdef GOA_KERBEROS_ENABLED
 #include "goakerberosprovider.h"
@@ -788,6 +789,9 @@ ensure_builtins_loaded (void)
 #ifdef GOA_WINDOWS_LIVE_ENABLED
       type = GOA_TYPE_WINDOWS_LIVE_PROVIDER;
 #endif
+#ifdef GOA_POCKET_ENABLED
+      type = GOA_TYPE_POCKET_PROVIDER;
+#endif
 #ifdef GOA_EXCHANGE_ENABLED
       type = GOA_TYPE_EXCHANGE_PROVIDER;
 #endif
@@ -1355,7 +1359,7 @@ goa_util_add_row_switch_from_keyfile_with_blurb (GtkGrid      *grid,
                               G_BINDING_BIDIRECTIONAL | G_BINDING_INVERT_BOOLEAN);
     }
 
-  hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 6);
+  hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 0);
   gtk_box_set_homogeneous (GTK_BOX (hbox), FALSE);
 
   if (blurb != NULL)
