@@ -43,86 +43,6 @@ G_BEGIN_DECLS
 typedef struct _GoaProviderClass GoaProviderClass;
 typedef struct _GoaProviderPrivate GoaProviderPrivate;
 
-/**
- * GoaProvider:
- *
- * The #GoaProvider structure contains only private data and should
- * only be accessed using the provided API.
- */
-struct _GoaProvider
-{
-  /*< private >*/
-  GObject parent_instance;
-  GoaProviderPrivate *priv;
-};
-
-/**
- * GoaProviderClass:
- * @parent_class: The parent class.
- * @get_provider_type: Virtual function for goa_provider_get_provider_type().
- * @get_provider_name: Virtual function for goa_provider_get_provider_name().
- * @get_provider_icon: Virtual function for goa_provider_get_provider_icon().
- * @get_provider_group: Virtual function for goa_provider_get_provider_group().
- * @get_provider_features: Virtual function for goa_provider_get_provider_features().
- * @add_account: Virtual function for goa_provider_add_account().
- * @refresh_account: Virtual function for goa_provider_refresh_account().
- * @build_object: Virtual function for goa_provider_build_object().
- * @ensure_credentials_sync: Virtual function for goa_provider_ensure_credentials_sync().
- * @show_account: Virtual function for goa_provider_show_account().
- * @get_credentials_generation: Virtual function for goa_provider_get_credentials_generation().
- *
- * Class structure for #GoaProvider.
- */
-struct _GoaProviderClass
-{
-  GObjectClass parent_class;
-
-  /* pure virtual */
-  const gchar *(*get_provider_type) (GoaProvider        *provider);
-  gchar       *(*get_provider_name) (GoaProvider        *provider,
-                                     GoaObject          *object);
-  GIcon       *(*get_provider_icon) (GoaProvider        *provider,
-                                     GoaObject          *object);
-  GoaObject   *(*add_account)       (GoaProvider        *provider,
-                                     GoaClient          *client,
-                                     GtkDialog          *dialog,
-                                     GtkBox             *vbox,
-                                     GError            **error);
-  gboolean     (*refresh_account)   (GoaProvider        *provider,
-                                     GoaClient          *client,
-                                     GoaObject          *object,
-                                     GtkWindow          *parent,
-                                     GError            **error);
-  void         (*show_account)      (GoaProvider         *provider,
-                                     GoaClient           *client,
-                                     GoaObject           *object,
-                                     GtkBox              *vbox,
-                                     GtkGrid             *grid,
-                                     GtkGrid             *dummy);
-  gboolean     (*build_object)      (GoaProvider        *provider,
-                                     GoaObjectSkeleton  *object,
-                                     GKeyFile           *key_file,
-                                     const gchar        *group,
-                                     GDBusConnection    *connection,
-                                     gboolean            just_added,
-                                     GError            **error);
-  /* virtual but with default implementation */
-  gboolean (*ensure_credentials_sync) (GoaProvider         *provider,
-                                       GoaObject           *object,
-                                       gint                *out_expires_in,
-                                       GCancellable        *cancellable,
-                                       GError             **error);
-  guint    (*get_credentials_generation) (GoaProvider   *provider);
-
-  /* pure virtual */
-  GoaProviderGroup (*get_provider_group) (GoaProvider   *provider);
-  GoaProviderFeatures  (*get_provider_features)     (GoaProvider   *provider);
-
-  /*< private >*/
-  /* Padding for future expansion */
-  gpointer goa_reserved[31];
-};
-
 GType        goa_provider_get_type                  (void) G_GNUC_CONST;
 const gchar *goa_provider_get_provider_type         (GoaProvider         *provider);
 gchar       *goa_provider_get_provider_name         (GoaProvider         *provider,
