@@ -35,6 +35,9 @@
  *
  * #GoaTelepathyFactory dynamically creates instances of #GoaTelepathyProvider
  * based on the protocols available through Telepathy.
+ *
+ * It accepts the protocol names from the Telepathy specification as
+ * @provider_name in goa_provider_factory_get_provider().
  */
 
 G_DEFINE_TYPE_WITH_CODE (GoaTelepathyFactory, goa_telepathy_factory, GOA_TYPE_PROVIDER_FACTORY,
@@ -50,7 +53,7 @@ static GoaProvider *
 get_provider (GoaProviderFactory *factory,
               const gchar        *provider_name)
 {
-  g_return_if_fail (GOA_IS_TELEPATHY_FACTORY (factory));
+  g_return_val_if_fail (GOA_IS_TELEPATHY_FACTORY (factory), NULL);
 
   return GOA_PROVIDER (goa_telepathy_provider_new_from_protocol_name (provider_name));
 }
