@@ -672,8 +672,8 @@ edit_personal_details (GoaObject  *goa_object,
   dialog = gtk_dialog_new_with_buttons (_("Personal Details"),
       parent,
       GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
-      GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
-      GTK_STOCK_OK, GTK_RESPONSE_OK,
+      _("_Cancel"), GTK_RESPONSE_CANCEL,
+      _("_OK"), GTK_RESPONSE_OK,
       NULL);
   gtk_window_set_resizable (GTK_WINDOW (dialog), FALSE);
   set_action_area_spacing (GTK_DIALOG (dialog));
